.. toctree::
   :maxdepth: 2

Palette
==================

.. autoclass:: SecretColors.Palette
        :members:

ColorWheel
==================

.. autoclass:: SecretColors.ColorWheel
        :members:

ColorMaps
=================

.. include:: map_intro.rst

ColorMapParent
----------------
.. autoclass:: SecretColors.cmaps.parent.ColorMapParent
        :members:

ColorMap
----------------
.. autoclass:: SecretColors.cmaps.ColorMap
        :members:

BrewerMap
----------------
.. autoclass:: SecretColors.cmaps.BrewerMap
        :members:


TableauMap
----------------
.. autoclass:: SecretColors.cmaps.TableauMap
        :members:

Utils
===================
.. automodule:: SecretColors.utils
        :members:

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
